@@ -114,7 +114,7 @@
 //! use fixedvec::FixedVec;
 //!
 //! #[no_mangle]
-//! pub extern fn main(argc: i32, argv: *const *const u8) -> i32 {
+//! pub extern fn main(_argc: i32, _argv: *const *const u8) -> i32 {
 //!     let mut preallocated_space = alloc_stack!([u8; 10]);
 //!     let mut vec = FixedVec::new(&mut preallocated_space);
 //!     assert_eq!(vec.len(), 0);
@@ -133,6 +133,25 @@
 //! // provide them ourselves in no_std.
 //! #[lang = "eh_personality"] extern "C" fn eh_personality() {}
 //! #[lang = "panic_fmt"] extern "C" fn panic_fmt() -> ! { loop {} }
+//!
+//! # // Needed to allow doctest to compile/link cleanly with nostd
+//! # #[allow(non_snake_case)]
+//! # #[no_mangle]
+//! # pub extern "C" fn _Unwind_Resume() -> ! { loop {} }
+//! ```
+//!
+//! If you're building for an embedded system, you will also likely want to
+//! disable stack unwinding by adding the following section(s) to your
+//! Cargo.toml:
+//!
+//! ```toml
+//! [profile.dev]
+//! panic = "abort"
+//!
+//! [profile.release]
+//! panic = "abort"
+//!
+//! # ..etc
 //! ```
 
 use core::hash::{Hash, Hasher};
@@ -179,10 +198,12 @@ pub struct FixedVec<'a, T: 'a + Copy> {
     len: usize,
 }
 
-pub use core::slice::Iter as Iter;
-pub use core::slice::IterMut as IterMut;
+pub use core::slice::Iter;
+pub use core::slice::IterMut;
 
-impl <'a, T> FixedVec<'a, T> where T: 'a + Copy {
+impl<'a, T> FixedVec<'a, T>
+    where T: 'a + Copy
+{
     /// Create a new `FixedVec` from the provided slice, in the process taking
     /// ownership of the slice.
     ///
@@ -370,7 +391,9 @@ impl <'a, T> FixedVec<'a, T> where T: 'a + Copy {
             self.len += 1;
             let mut i = self.len;
             loop {
-                if i == index { break; }
+                if i == index {
+                    break;
+                }
                 self.memory[i] = self.memory[i - 1];
                 i -= 1;
             }
@@ -545,7 +568,9 @@ impl <'a, T> FixedVec<'a, T> where T: 'a + Copy {
     /// assert_eq!(vec.as_slice(), &[2, 4, 6]);
     /// # }
     /// ```
-    pub fn map_in_place<F>(&mut self, f: F) where F: Fn(&mut T) {
+    pub fn map_in_place<F>(&mut self, f: F)
+        where F: Fn(&mut T)
+    {
         for i in 0..self.len {
             f(&mut self.memory[i]);
         }
@@ -693,11 +718,15 @@ impl <'a, T> FixedVec<'a, T> where T: 'a + Copy {
     /// assert_eq!(vec.as_slice(), &[2, 4]);
     /// # }
     /// ```
-    pub fn retain<F>(&mut self, f: F) where F: Fn(&T) -> bool {
+    pub fn retain<F>(&mut self, f: F)
+        where F: Fn(&T) -> bool
+    {
         let mut head: usize = 0;
         let mut tail: usize = 0;
         loop {
-            if head >= self.len { break; }
+            if head >= self.len {
+                break;
+            }
             if f(&self.memory[head]) {
                 self.memory[tail] = self.memory[head];
                 tail += 1;
@@ -806,7 +835,9 @@ impl <'a, T> FixedVec<'a, T> where T: 'a + Copy {
     }
 }
 
-impl<'a, T> FixedVec<'a, T> where T: 'a + Copy + PartialEq<T> {
+impl<'a, T> FixedVec<'a, T>
+    where T: 'a + Copy + PartialEq<T>
+{
     /// Removes consecutive repeated elements in the vector in O(N) time.
     ///
     /// If the vector is sorted, this removes all duplicates.
@@ -825,11 +856,15 @@ impl<'a, T> FixedVec<'a, T> where T: 'a + Copy + PartialEq<T> {
     /// # }
     /// ```
     pub fn dedup(&mut self) {
-        if self.len <= 1 { return; }
+        if self.len <= 1 {
+            return;
+        }
         let mut head: usize = 1;
         let mut tail: usize = 0;
         loop {
-            if head >= self.len { break; }
+            if head >= self.len {
+                break;
+            }
             if self.memory[head] != self.memory[tail] {
                 tail += 1;
                 self.memory[tail] = self.memory[head];
@@ -840,11 +875,6 @@ impl<'a, T> FixedVec<'a, T> where T: 'a + Copy + PartialEq<T> {
     }
 }
 
-///////////////////////////////////////////////////////////////////////////////
-// Common trait implementations
-///////////////////////////////////////////////////////////////////////////////
-
-
 impl<'a, T: Copy> IntoIterator for &'a FixedVec<'a, T> {
     type Item = &'a T;
     type IntoIter = Iter<'a, T>;
@@ -863,25 +893,35 @@ impl<'a, T: Copy> IntoIterator for &'a mut FixedVec<'a, T> {
     }
 }
 
-impl<'a, T> Hash for FixedVec<'a, T> where T: Copy + Hash {
+impl<'a, T> Hash for FixedVec<'a, T>
+    where T: Copy + Hash
+{
     #[inline]
     fn hash<H: Hasher>(&self, state: &mut H) {
         Hash::hash(&*self.memory, state)
     }
 }
 
-impl <'a, T> Extend<T> for FixedVec<'a, T> where T: Copy {
-    fn extend<I: IntoIterator<Item=T>>(&mut self, iterable: I) {
-        if self.available() == 0 { return; }
+impl<'a, T> Extend<T> for FixedVec<'a, T>
+    where T: Copy
+{
+    fn extend<I: IntoIterator<Item = T>>(&mut self, iterable: I) {
+        if self.available() == 0 {
+            return;
+        }
         for n in iterable {
             self.memory[self.len] = n;
             self.len += 1;
-            if self.available() == 0 { break; }
+            if self.available() == 0 {
+                break;
+            }
         }
     }
 }
 
-impl<'a, T> ops::Index<usize> for FixedVec<'a, T> where T: Copy {
+impl<'a, T> ops::Index<usize> for FixedVec<'a, T>
+    where T: Copy
+{
     type Output = T;
 
     #[inline]
@@ -890,24 +930,28 @@ impl<'a, T> ops::Index<usize> for FixedVec<'a, T> where T: Copy {
     }
 }
 
-impl<'a, T> ops::IndexMut<usize> for FixedVec<'a, T> where T: Copy {
+impl<'a, T> ops::IndexMut<usize> for FixedVec<'a, T>
+    where T: Copy
+{
     #[inline]
     fn index_mut(&mut self, index: usize) -> &mut T {
         &mut (self.memory)[index]
     }
 }
 
-impl<'a, T> PartialEq for FixedVec<'a, T> where T: Copy + PartialEq {
+impl<'a, T> PartialEq for FixedVec<'a, T>
+    where T: Copy + PartialEq
+{
     fn eq(&self, other: &FixedVec<'a, T>) -> bool {
-        if self.len() != other.len() { return false; }
+        if self.len() != other.len() {
+            return false;
+        }
 
-        (0..self.len()).all(|i| {
-            self[i] == other[i]
-        })
+        (0..self.len()).all(|i| self[i] == other[i])
     }
 }
 
-impl<'a, T> Eq for FixedVec<'a, T> where T: Copy + Eq { }
+impl<'a, T> Eq for FixedVec<'a, T> where T: Copy + Eq {}
 
 #[cfg(test)]
 mod test {
@@ -928,8 +972,8 @@ mod test {
         assert!(vec.push_all(&[] as &[u8]).is_ok());
         assert!(vec.push_all(&[1]).is_err());
         vec.clear();
-        vec.map_in_place(|x: &mut u8| { *x = 1 });
-        vec.retain(|_: &u8| { true });
+        vec.map_in_place(|x: &mut u8| *x = 1);
+        vec.retain(|_: &u8| true);
         vec.dedup();
         {
             let mut iter = vec.iter();
